@@ -78,9 +78,9 @@ def test_vars():
 
 @with_setup(setup=cleanup)
 def test_options():
-    eq(vim.options['compatible'], True)
-    vim.options['compatible'] = False
-    eq(vim.options['compatible'], False)
+    eq(vim.options['listchars'], 'eol:$')
+    vim.options['listchars'] = 'tab:xy'
+    eq(vim.options['listchars'], 'tab:xy')
 
 
 @with_setup(setup=cleanup)
